@@ -20,6 +20,7 @@ import helpsk.color as hcolor
 import helpsk.pandas_style as hstyle
 import helpsk.string as hstring
 # pylint: disable=too-many-locals
+from helpsk.pandas import get_numeric_columns, get_non_numeric_columns
 from helpsk.exceptions import HelpskParamValueError
 from helpsk.plot import STANDARD_WIDTH_HEIGHT
 from helpsk.validation import assert_true
@@ -528,6 +529,15 @@ class SearchCVParser:
         cross validated."""
         return len(self.parameter_iterations)
 
+    @property
+    def numeric_parameters(self) -> List[str]:
+        return [x for x in get_numeric_columns(dataframe=self.to_dataframe()) if x in self.parameter_names]
+
+    @property
+    def non_numeric_parameters(self) -> List[str]:
+        return [x for x in get_non_numeric_columns(dataframe=self.to_dataframe())
+                if x in self.parameter_names]
+
     @property
     def number_of_scores(self) -> int:
         """The number of scores passed to the SearchCV object"""
@@ -581,6 +591,7 @@ class SearchCVParser:
         """The index of best primary score."""
         return self.primary_score_best_indexes[0]
 
+    @property
     def best_primary_score_params(self) -> dict:
         """
         The "best" score (could be the highest or lowest depending on `higher_score_is_better`) associated
