@@ -289,6 +289,9 @@ class TestSklearnEval(unittest.TestCase):
         self.assertEqual(len(parser.score_standard_errors(score_name=parser.score_names[3])),
                          parser.number_of_iterations)
 
+        self.assertEqual(parser.numeric_parameters, ['n_estimators'])
+        self.assertEqual(parser.non_numeric_parameters, ['max_features', 'encoder'])
+
         for score in parser.score_names:
             assert_np_arrays_are_close(np.array(parser.test_score_averages[score]),
                                        grid_search_credit.cv_results_[f'mean_test_{score}'])
@@ -376,7 +379,7 @@ class TestSklearnEval(unittest.TestCase):
                          np.nanmax(grid_search_credit.cv_results_['mean_test_ROC/AUC']))
 
         self.assertTrue(all([parser.to_dataframe().loc[parser.best_primary_score_index, key] == value
-                             for key, value in parser.best_primary_score_params().items()]))
+                             for key, value in parser.best_primary_score_params.items()]))
 
         self.assertEqual(parser.best_primary_score, parser_from_dict.best_primary_score)
         self.assertEqual(parser.best_primary_score, parser_from_yaml.best_primary_score)
@@ -506,6 +509,10 @@ class TestSklearnEval(unittest.TestCase):
         self.assertEqual(len(parser.score_standard_errors(score_name=parser.score_names[0])),
                          parser.number_of_iterations)
 
+        self.assertEqual(parser.numeric_parameters, ['model__n_estimators'])
+        self.assertEqual(parser.non_numeric_parameters, ['model__max_features',
+                                                         'preparation__non_numeric_pipeline__encoder_chooser__transformer'])
+
         assert_np_arrays_are_close(np.array(parser.test_score_averages[parser.primary_score_name]),
                                    grid_search_credit.cv_results_['mean_test_score'])
         assert_np_arrays_are_close(np.array(parser.test_score_averages[parser.primary_score_name]),
@@ -572,13 +579,13 @@ class TestSklearnEval(unittest.TestCase):
                          np.nanmax(grid_search_credit.cv_results_['mean_test_score']))
 
         self.assertTrue(all([parser.to_dataframe().loc[parser.best_primary_score_index, key] == value
-                             for key, value in parser.best_primary_score_params().items()]))
+                             for key, value in parser.best_primary_score_params.items()]))
 
-        self.assertEqual(parser.best_primary_score_params()['model__max_features'],
+        self.assertEqual(parser.best_primary_score_params['model__max_features'],
                          grid_search_credit.best_params_['model__max_features'])
-        self.assertEqual(parser.best_primary_score_params()['model__n_estimators'],
+        self.assertEqual(parser.best_primary_score_params['model__n_estimators'],
                          grid_search_credit.best_params_['model__n_estimators'])
-        self.assertEqual(parser.best_primary_score_params()['preparation__non_numeric_pipeline__encoder_chooser__transformer'],
+        self.assertEqual(parser.best_primary_score_params['preparation__non_numeric_pipeline__encoder_chooser__transformer'],
                          str(grid_search_credit.best_params_['preparation__non_numeric_pipeline__encoder_chooser__transformer']))
 
         self.assertEqual(parser.best_primary_score, parser_from_dict.best_primary_score)
@@ -696,6 +703,9 @@ class TestSklearnEval(unittest.TestCase):
         self.assertEqual(len(parser.score_standard_errors(score_name=parser.score_names[1])),
                          parser.number_of_iterations)
 
+        self.assertEqual(parser.numeric_parameters, ['model__n_estimators'])
+        self.assertEqual(parser.non_numeric_parameters, ['model__max_features'])
+
         for score in parser.score_names:
             assert_np_arrays_are_close(np.array(parser.test_score_averages[score]),
                                        grid_search_housing.cv_results_[f'mean_test_{score}'] * -1)
@@ -783,7 +793,7 @@ class TestSklearnEval(unittest.TestCase):
                          np.nanmin(grid_search_housing.cv_results_['mean_test_RMSE'] * -1))
 
         self.assertTrue(all([parser.to_dataframe().loc[parser.best_primary_score_index, key] == value
-                             for key, value in parser.best_primary_score_params().items()]))
+                             for key, value in parser.best_primary_score_params.items()]))
 
         self.assertEqual(parser.best_primary_score, parser_from_dict.best_primary_score)
         self.assertEqual(parser.best_primary_score, parser_from_yaml.best_primary_score)
